@@ -15,8 +15,13 @@ def list(collection: str, params: dict = {}):
 
 @app.post('/{collection}')
 def create(collection: str, body: dict):
+    db.table(collection, body)
     return db.create(collection, body)
 
+@app.delete('/{collection}')
+def drop(collection: str):
+    return db.drop(collection)
+
 @app.get('/{collection}/{id}')
 def read(collection: str, id: str):
     return db.read(collection, id)
